function [model] = def_model(params,v_rig,x,use_hl)
    model = HeaveModel(params);
    model.continuous_circulation = true;
    model.pressuredropexceldata = true;
    model.coupling_pi_pa = true;
    model.choke_mode = 'dynamic';
    model.useHeaveLock = use_hl; 
    model.q_backpressure_pump = @(t) 0;
    model.positionHeaveLock = x;
    
    % Fungerer
%     model.q_pump = @(t) -params.q_pump;
    model.q_pump = @(t) -( ((t<params.t_p1) + (t>(params.t_p2+params.delta_t_p2)))*params.q_pump + ...
        ((t>(params.t_p1+params.delta_t_p1)).*(t<params.t_p2))*params.q_pump_con + ...
        ((t>=params.t_p1).*(t<=(params.t_p1+params.delta_t_p1))).*(params.q_pump-(params.q_pump-params.q_pump_con)/params.delta_t_p1*(t-params.t_p1)) + ...
        ((t>=params.t_p2).*(t<=(params.t_p2+params.delta_t_p2))).*(params.q_pump_con-(params.q_pump_con-params.q_pump)/params.delta_t_p2*(t-params.t_p2)) );
    
    % Fungerer ikke, m legge til choke-karakteristikk i modell 
    model.choke_opening = @(t) ((t<params.t_c1) + (t>(params.t_c2+params.delta_t_c2)))*params.u_c + ...
        (t>(params.t_c1+params.delta_t_c1)).*(t<params.t_c2)*params.u_c_con + ...
        (t>=params.t_c1).*(t<=(params.t_c1+params.delta_t_c1)).*(params.u_c+(params.u_c_con-params.u_c)/params.delta_t_c1*(t-params.t_c1)) + ...
        (t>=params.t_c2).*(t<=(params.t_c2+params.delta_t_c2)).*(params.u_c_con+(params.u_c-params.u_c_con)/params.delta_t_c2*(t-params.t_c2));
    
    % Fungerer 
    model.heave_comp = @(t) heave_comp(t,params); 
    model.v_rig = @(t) 2*v_rig(t).*model.heave_comp(t);  
end

function out = heave_comp(t,prm)
    disconnect = ((t-prm.t_h1).^2.*(3/prm.delta_t_h1^2 - 2/prm.delta_t_h1^3*(t-prm.t_h1))).*(t<=prm.t_h1+prm.delta_t_h1).*(t>prm.t_h1);
    connection = (t>prm.t_h1+prm.delta_t_h1).*(t<=prm.t_h2);
    connect = -(-1+(t-prm.t_h2).^2.*(3/prm.delta_t_h2^2 - 2/prm.delta_t_h2^3*(t-prm.t_h2))).*(t<=prm.t_h2+prm.delta_t_h2).*(t>prm.t_h2);
    out = disconnect + connection + connect;
end
