function [param] = def_params(q_pump, length, u_hl0, p_hl_drop, u_min, t_hl_start)
    param.beta      = 2.2e9;                    % mud bulk modulus
    param.E         = 206.8e9;                  % pipe Young's modulus
    param.rho       = 1420;                     % mud density
    param.rho_p     = 5000;                     % pipe density
    param.L         = length;                    % well length
    param.A_a       = 0.0274;                   % A annulus
    param.A_i       = 0.0118;                   % A in pipe
    param.A_p       = 0.003;                    % A pipe
    param.A_bha     = param.A_i + param.A_a;    % A bottomhole assembly
    param.A_bit     = 0*param.A_i;
    param.beta_i    = 1.84e9;                   % effective bulk modulus in pipe
    param.beta_a    = 1.6e9;                    % effective bulk modulus in annulus
    param.K         = 5424;                     % bha damping coefficient
    param.m_BHA     = 400;                      % mass bottomhole assembly

    param.m_BHA = 12000;        % mass bottom hole assembly (excel data)
    param.l_BHA = 100;          % length bottom hole assembly 
    
    %param.kp        = 0.095;        % pipe damping coefficient
    param.kp        = 0;        % ToDo
    param.Ai_pa     = -9.67e-11;    % area-change coefficient
    param.Aa_pi     = -4.18e-11;    % area change coefficient
    param.fi        = 1.45e-12;     % Hoop-strain coefficient
    param.fa        = 1.45e-12;     % Hoop-strain coefficient
    param.nu        = 30e-6;        % kinematic viscosity
    param.N = 30;   % number discretization elements - 50 is sufficient most of the time
    param.g = 9.81;

    

   % HeaveLock paramters
    param.p_hl_drop     = p_hl_drop;
    param.k_hl          = 1500/60000/(0.6*sqrt(p_hl_drop + param.rho*param.g*param.L/param.N));
    % q_cont / (u_hlnom sqrt )
    param.u_min         = u_min;
    param.u_hl0         = 0.3;          % HeaveLock opening from t = t_hl1+delta_t_hl1
    param.u_hl_init     = 1;            % HeaveLock opening from t=0
    param.t_hl1         = 100;
    param.delta_t_hl1   = 100;
    param.t_hl_start    = param.t_hl1 + param.delta_t_hl1 + 100;
    param.t_hl_end      = 1100;
    param.t_hl2         = param.t_hl_end + 80;
    param.delta_t_hl2   = 100;
    
   
    
    % Pump control parameters
    param.q_pump        = q_pump;               % Pump rate during drilling
    param.q_pump_con    = 0.6*param.q_pump;     % Pump rate during connection
           % Duration of ramp
    
    

    
    
    
    
    % Choke control parameters
    param.C_d           = 0.095;
    param.A_choke       = 5*param.A_p;
    param.u_c           = 1;                    % Opening during drilling
    param.u_c_con       = 0.465;  
    
    %START/RAMP DOWN PUMP
    param.t_p1          = 100;                              % Time when starting to ramp down pump rate
    param.delta_t_p1    = 80; 
    
    % START/CLOSE CHOKE
    param.t_c1          = param.t_p1 + (param.delta_t_p1/8);                                                % Time when starting to close the choke
    param.delta_t_c1    = 80;        % Duration of closing
    
    %END/RAMP UP PUMP
    param.t_p2          = param.t_hl2 + param.delta_t_hl2 + 10;%800;%param.t_hl_end;                               % Time to ramp up pump rate
    param.delta_t_p2    = 80;                 % Duration of ramp
    
    % END/OPEN CHOKE
    param.t_c2          = param.t_p2 + (param.delta_t_p2/8);%801;                       % Time when starting to open the choke
    param.delta_t_c2    = 80; % Duration of opening
    
    
    
    
    
    
    % Heave compensation
    param.t_h1          = param.t_hl_start+20;             % Time when heave compensation is starting to disconnect
    param.delta_t_h1    = 30;                   % Duration of disonnection procedure
    param.t_h2          = param.t_hl_end-30;               % Time when heave compensation is starting to connect
    param.delta_t_h2    = 30;                   % Duration of connection procedure


end

